==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/list_css_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCssClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'css_clusters': 'list[CssClusterDto]',
        'count': 'int'
    }

    attribute_map = {
        'css_clusters': 'css_clusters',
        'count': 'count'
    }

    def __init__(self, css_clusters=None, count=None):
        """ListCssClusterResponse

        The model defined in huaweicloud sdk

        :param css_clusters: CSS集群列表
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        :param count: css集群总数
        :type count: int
        """
        
        super(ListCssClusterResponse, self).__init__()

        self._css_clusters = None
        self._count = None
        self.discriminator = None

        if css_clusters is not None:
            self.css_clusters = css_clusters
        if count is not None:
            self.count = count

    @property
    def css_clusters(self):
        """Gets the css_clusters of this ListCssClusterResponse.

        CSS集群列表

        :return: The css_clusters of this ListCssClusterResponse.
        :rtype: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        """
        return self._css_clusters

    @css_clusters.setter
    def css_clusters(self, css_clusters):
        """Sets the css_clusters of this ListCssClusterResponse.

        CSS集群列表

        :param css_clusters: The css_clusters of this ListCssClusterResponse.
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        """
        self._css_clusters = css_clusters

    @property
    def count(self):
        """Gets the count of this ListCssClusterResponse.

        css集群总数

        :return: The count of this ListCssClusterResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListCssClusterResponse.

        css集群总数

        :param count: The count of this ListCssClusterResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCssClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.154-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/list_css_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCssClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'css_clusters': 'list[CssClusterDto]',
        'count': 'int'
    }

    attribute_map = {
        'css_clusters': 'css_clusters',
        'count': 'count'
    }

    def __init__(self, css_clusters=None, count=None):
        r"""ListCssClusterResponse

        The model defined in huaweicloud sdk

        :param css_clusters: CSS集群列表
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        :param count: css集群总数
        :type count: int
        """
        
        super(ListCssClusterResponse, self).__init__()

        self._css_clusters = None
        self._count = None
        self.discriminator = None

        if css_clusters is not None:
            self.css_clusters = css_clusters
        if count is not None:
            self.count = count

    @property
    def css_clusters(self):
        r"""Gets the css_clusters of this ListCssClusterResponse.

        CSS集群列表

        :return: The css_clusters of this ListCssClusterResponse.
        :rtype: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        """
        return self._css_clusters

    @css_clusters.setter
    def css_clusters(self, css_clusters):
        r"""Sets the css_clusters of this ListCssClusterResponse.

        CSS集群列表

        :param css_clusters: The css_clusters of this ListCssClusterResponse.
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.CssClusterDto`]
        """
        self._css_clusters = css_clusters

    @property
    def count(self):
        r"""Gets the count of this ListCssClusterResponse.

        css集群总数

        :return: The count of this ListCssClusterResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListCssClusterResponse.

        css集群总数

        :param count: The count of this ListCssClusterResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCssClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
